@@ -39,20 +39,27 @@ if [ $retval != 0 ]; then
 fi
 
 extract `(cd $TARGET/var/cache/apt/archives && \
-	for i in *.deb; do dpkg-deb --field $i Priority | grep ^required \
-	&& echo $i; done) | cut -d _ -f 1`
+	for i in *.deb ; do \
+		if [ -z "${i##libc0.3_*}" ] || \
+		   [ -z "${i##libcrypt*}" ] || \
+		   [ -z "${i##libc-bin*}" ] || \
+		   [ -z "${i##libtinfo*}" ] || \
+		   [ -z "${i##libbsd0*}" ] || \
+		   [ -z "${i##libmd0*}" ] || \
+		   [ -z "${i##libacl1*}" ] || \
+		   [ -z "${i##libattr*}" ] || \
+		   [ -z "${i##libpcre*}" ] || \
+		   [ -z "${i##liblzma*}" ] || \
+		   [ -z "${i##libzstd*}" ] || \
+		   [ -z "${i##debianutils_*}" ] || \
+		   [ -z "${i##gnumach-image-*}" ] || \
+		   dpkg-deb --field $i Priority | grep ^required ; then \
+			echo $i ; \
+		fi ; \
+	done) | cut -d _ -f 1`
 
-if [ -e $TARGET/var/cache/apt/archives/gnumach-image-1.8-486_* ] ; then
-        extract gnumach-image-1.8-486
-	# place symlink for compatibility with update-grub (/etc/grub.d/30_os-prober)
-	ln -s gnumach-1.8-486.gz "$TARGET/boot/gnumach.gz"
-fi
-
-if [ -e $TARGET/var/cache/apt/archives/gnumach-image-1.8-486-up_* ] ; then
-        extract gnumach-image-1.8-486-up
-	# place symlink for compatibility with update-grub (/etc/grub.d/30_os-prober)
-	ln -s gnumach-1.8-486-up.gz "$TARGET/boot/gnumach.gz"
-fi
+# place symlink for compatibility with update-grub (/etc/grub.d/30_os-prober)
+( cd $TARGET/boot ; ln -s $( ls gnumach-*.gz | tail -n 1 ) gnumach.gz )
 
 if [ -e $TARGET/var/cache/apt/archives/libbz2-1.0_* ] ; then
         extract libbz2-1.0
@@ -62,6 +69,21 @@ if [ -e $TARGET/var/cache/apt/archives/libparted2_* ] ; then
         extract libparted2
 fi
 
+mv $TARGET/lib/* $TARGET/usr/lib/
+for i in $TARGET/lib/* ; do mv $i/* ${i/\/lib\//\/usr\/lib\/}/ ; done
+rmdir $TARGET/lib/*
+rmdir $TARGET/lib
+ln -s usr/lib $TARGET/lib
+mv $TARGET/bin/* $TARGET/usr/bin/
+rmdir $TARGET/bin
+ln -s usr/bin $TARGET/bin
+mv $TARGET/sbin/* $TARGET/usr/sbin/
+rmdir $TARGET/sbin
+ln -s usr/sbin $TARGET/sbin
+
+ln -s which.debianutils $TARGET/usr/bin/which
+ln -s bash $TARGET/bin/sh
+
 x_feign_install dpkg
 if [ "$DEB_TARGET_GNU_SYSTEM" = "gnu" ] ; then
 	x_feign_install hurd
